@@ -5,7 +5,6 @@ import gc
 import pickle
 import numpy as np
 import pandas as pd
-import datetime as dt
 from pathlib import Path
 
 from .cl_SQLConnector import *
@@ -50,6 +49,8 @@ class TablasVC(SQLConnector):
         self.conjuntogeneradores = None
         self.habilitaciones = None
         self.tipohabilitaciones = None
+        self.marcas_smec = None
+        self.medidores_smec = None
         
         self._idApiC_a_nemo = {}
         self._nemo_a_uc = {}
@@ -650,12 +651,17 @@ class TablasVC(SQLConnector):
             self.tipogenerador = pd.concat([self.tipogenerador,df_tmp],ignore_index=True)
     
     def __asignar_datos_conjuntogeneradores(self,mensajes=False):
-        self.conjuntogeneradores = pd.merge(left=self.dfs['conjuntogeneradores'],right=self.tipoequipo,left_on='idGenerador',right_on='idtipoEquipo',suffixes=('_or',''))\
-            .drop(columns=['idGenerador','idtipoEquipo','cantidad'])\
+        self.conjuntogeneradores = (pd
+            .merge(
+                left=self.dfs['conjuntogeneradores'],
+                right=self.tipoequipo,
+                left_on='idGenerador',
+                right_on='idtipoEquipo',
+                suffixes=('_or',''))
+            .drop(columns=['idGenerador','idtipoEquipo','cantidad'])
             .rename(columns={
                 'idTipoGenerador_or':'Agrupamiento',
-                'idTipoGenerador':'GenType'
-            }
+                'idTipoGenerador':'GenType'})
         )
                             
         mapeo_ucs = self._crear_dict(self.central,'idcentral','unidadComercial')
@@ -673,6 +679,31 @@ class TablasVC(SQLConnector):
         self.conjuntogeneradores['Agrupamiento'] = self.conjuntogeneradores['Agrupamiento'].str.upper()
         self.conjuntogeneradores['equipo'] = self.conjuntogeneradores['equipo'].str.upper()
    
+    def __asignar_datos_marcas_smec(self,mensajes=False):
+
+        self.marcas_smec = (self.dfs['marca_med_smec']
+          .set_index('idmarca')
+          .rename(columns={'nombre':'Marca'}))
+    
+    def __asignar_datos_smec_(self,mensajes=False):
+        
+        tipo_medidor= {i:v for i,v in enumerate(['Control','Principal',] + ['Principal','Control']*3)}
+        dict_uc_nemo = (self.central
+            [['idcentral','unidadComercial','nemoCammesa']]
+            .set_index('idcentral')
+            .to_dict()
+        )
+
+        self.medidores_smec = (self.dfs['medidor_smec']
+            .assign(**{c:lambda df_, c=c: df_.idcentral.map(dict_uc_nemo[c]) for c in dict_uc_nemo.keys()})
+            .assign(
+                Marca = lambda df_: df_.idmarca.map(self.marcas_smec['Marca'].to_dict()),
+                Tipo = lambda df_: df_.tipo.map(tipo_medidor))
+            .rename(columns={'nombre':'Medidor','nemoCammesa':'Nemo','unidadComercial':'UC',})
+            .drop(columns=['idmarca','tipo'])
+            .loc[:,['idmedidor','idcentral','Nemo','UC','Medidor','Tipo','Marca','rel_tv']]
+        )
+   
     def __asignar_datos(self,tabla,mensajes=False):
         if tabla == 'central':
             self.__asignar_datos_central(mensajes=mensajes)
@@ -709,6 +740,12 @@ class TablasVC(SQLConnector):
             
         elif tabla == 'incidencias':
             self.__asignar_datos_incidencias(mensajes=mensajes)
+            
+        elif tabla == 'marca_med_smec':
+            self.__asignar_datos_marcas_smec(mensajes=mensajes)
+            
+        elif tabla == 'medidor_smec':
+            self.__asignar_datos_smec_(mensajes=mensajes)
         else:
             pass
 
@@ -752,6 +789,8 @@ class TablasVC(SQLConnector):
             'conjuntogeneradores',
             'tipohabilitaciones',
             'habilitaciones',
+            'marca_med_smec',
+            'medidor_smec',
         ]
         
         self.__consultar(tablas,mensajes=mensajes,desconectar=False)
@@ -820,7 +859,8 @@ class TablasVC(SQLConnector):
                 self.conjuntogeneradores.to_excel(w,sheet_name='conjuntogeneradores',index=False)
                 self.habilitaciones.to_excel(w,sheet_name='habilitaciones',index=False)
                 self.tipohabilitaciones.to_excel(w,sheet_name='tipohabilitaciones',index=False)
-            
+                self.marcas_smec.to_excel(w,sheet_name='marcas_smec',index=False)
+                self.medidores_smec.to_excel(w,sheet_name='medidores_smec',index=False)
         if incidencias and hay_incidencias:
             if mensajes: print(f"Guardando backup local de las incidencias en {self.__archivo_incidencias}")
             dict_inc = {
@@ -853,6 +893,14 @@ class TablasVC(SQLConnector):
                 self.conjuntogeneradores = dict_dfs['conjuntogeneradores']
                 self.habilitaciones = dict_dfs['habilitaciones']
                 self.tipohabilitaciones = dict_dfs['tipohabilitaciones']
+                try:
+                    self.marcas_smec = dict_dfs['marcas_smec']
+                except:
+                    pass
+                try:
+                    self.medidores_smec = dict_dfs['medidores_smec']
+                except:
+                    pass
                 
                 self.consultar_idsApiCammesa()
                 self.consultar_ucs(solo_CROM=self.solo_CROM)
