@@ -37,7 +37,7 @@ def fecha_op(fecha,prevenir_futuro=False):
     fecha = validar_fecha(fecha,prevenir_futuro=prevenir_futuro)
     if hora_op(fecha) == 24 :
         if fecha.hour == 0:
-            return (fecha.date() + __dt.timedelta(days=-1))
+            return (fecha.date() - __dt.timedelta(days=1))
         else:
             return fecha.date()
     else:
